package testcdi.initialization;

import java.io.File;

public class Environment {

    public static final String BTOA_DOMAIN_NAME = "BTOA";

    /**
     * Returns the home path of the application server
     *
     * @return The home path of the application server
     */
    public static String getAppServerHomePath() {
        return System.getProperty("com.sun.aas.installRoot");
    }

    /**
     * Returns the config path of the application server
     *
     * @return The config path of the application server
     */
    public static String getAppServerConfigPath() {
        return System.getProperty("com.sun.aas.configRoot");
    }

    /**
     * Returns the home path of the domain
     *
     * @return The home path of the domain
     */
    public static String getDomainHomePath() {
        return System.getProperty("com.sun.aas.instanceRoot");
    }

    /**
     * Returns the config path of the domain
     *
     * @return The config path of the domain
     */
    public static String getDomainConfigPath() {
        String domainHomePath = getDomainHomePath();
        return domainHomePath == null ? null : domainHomePath + File.separator + "config";
    }

    /**
     * Returns the log config path of the domain
     *
     * @return The log config path of the domain
     */
    public static String getDomainLogConfigPath() {
        String domainConfigPath = getDomainConfigPath();
        return domainConfigPath == null ? null : domainConfigPath + File.separator + "log";
    }

    /**
     * Returns the log path of the domain
     *
     * @return The log path of the domain
     */
    public static String getDomainLogPath() {
        String domainHomePath = getDomainHomePath();
        return domainHomePath == null ? null : domainHomePath + File.separator + "logs";
    }
}
