package testcdi.persistence.dao;

import javax.persistence.EntityManager;

public abstract class BaseDAO<T> implements DAO<T> {

    /**
     * Returns the entity manager
     *
     * @return The entity manager
     */
    protected abstract EntityManager getEntityManager();

    /**
     * @see DAO#add(Object)
     */
    public void add(T entity) {
        getEntityManager().persist(entity);
    }

    /**
     * @see DAO#update(Object)
     */
    public T update(T entity) {
        return getEntityManager().merge(entity);
    }

    /**
     * @see DAO#remove(Object)
     */
    public void remove(T entity) {
        getEntityManager().remove(entity);
    }

    /**
     * @see DAO#remove(Class, Object)
     */
    public void remove(Class<T> entityClass, Object primaryKey) {
        remove(get(entityClass, primaryKey));
    }

    /**
     * @see DAO#get(Class, Object)
     */
    public T get(Class<T> entityClass, Object primaryKey) {
        return getEntityManager().find(entityClass, primaryKey);
    }
}
