package testcdi.persistence.dao;

public interface DAO<T> {

    /**
     * Adds (persists) the given entity. If exists (an entity with the same
     * primary key in the database), a primary key violation exception will
     * be thrown
     *
     * @param entity The entity to add
     */
    public void add(T entity);

    /**
     * Updates the given entity
     *
     * (The entity can be detached or attached)
     *
     * @param entity The entity to update
     * @return The updated entity
     */
    public T update(T entity);

    /**
     * Removes an entity
     *
     * @param entity The entity to remove
     */
    public void remove(T entity);

    /**
     * Removes an entity
     *
     * @param entityClass The class of the entity
     * @param primaryKey The primary of the entity to find
     */
    public void remove(Class<T> entityClass, Object primaryKey);

    /**
     * Finds an entity by its primary key
     *
     * @param entityClass The class of the entity
     * @param primaryKey The primary of the entity to find
     * @return The entity
     */
    public T get(Class<T> entityClass, Object primaryKey);
}
