package testcdi.persistence.inject;

import javax.enterprise.inject.Produces;
import javax.persistence.EntityManager;

public class EntityManagerProducer {

    public static final String MNG_DB_PERSISTENCE_UNIT_NAME = "management";
    public static final String DATA_DB_PERSISTENCE_UNIT_NAME = "data";

    /**
     * Producer method for the entity manager of the management DB
     *
     * @return The entity manager of the management DB
     */
    @Produces @MngDb
    private EntityManager getMngDbEntityManager() {
        return EntityManagerProvider.getEntityManager(MNG_DB_PERSISTENCE_UNIT_NAME);
    }

    /**
     * Producer method for the entity manager of the data DB
     *
     * Note, currently the code for looking up the entity manager of the management and
     * the data DB is identical. However, in future versions, when we support multi-tenant
     * environments this method will have a different implementation which will take into 
     * consideration the tenant id
     *
     * @return The entity manager of the data DB
     */
    @Produces @DataDb 
    private EntityManager getDataDbEntityManager() {
        return EntityManagerProvider.getEntityManager(DATA_DB_PERSISTENCE_UNIT_NAME);
    }
}
