package testcdi.persistence.inject;

import testcdi.persistence.exceptions.GeneralPersistenceException;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import javax.naming.Context;
import javax.naming.InitialContext;
import javax.persistence.EntityManager;

public class EntityManagerProvider {

    private static final Logger LOG = LoggerFactory.getLogger(EntityManagerProducer.class);
    
    private static final String JNDI_ENV_PREFIX = "java:comp/env/";

    /**
     * Looks up and returns the entity manager according to the given persist unit name
     *
     * @param persistUnitName The persistence unit name
     * @return The entity manager
     */
    public static EntityManager getEntityManager(String persistUnitName) {
        return getEntityManager(persistUnitName, null);
    }

    /**
     * Looks up and returns the entity manager according to the given persist unit name
     * and context
     *
     * @param persistUnitName The persistence unit name
     * @param persistContextRefPrefix The persistence context ref prefix
     * @return The entity manager
     */
    public static EntityManager getEntityManager(String persistUnitName, String persistContextRefPrefix) {
        try {
            Context ic = new InitialContext();
            if (persistContextRefPrefix == null) {
                persistContextRefPrefix = (String)
                        ic.lookup(JNDI_ENV_PREFIX + "persistenceContextRefPrefix");
            }
            return (EntityManager) ic.lookup(JNDI_ENV_PREFIX + persistContextRefPrefix + persistUnitName);
        } catch (Exception e) {
            String error = "Failed to create entity manager for persistence unit " +
                    JNDI_ENV_PREFIX + persistContextRefPrefix + persistUnitName;
            LOG.error(error, e);
            throw new GeneralPersistenceException(error, e);
        }
    }
}
